@@ -26,10 +26,6 @@ import itertools
 import re
 import os
 
-from six import iterkeys, iteritems
-from six.moves import xrange as range
-from six.moves import zip
-
 from avocado.core import tree
 from avocado.core import varianter
 from avocado.core import output
@@ -42,7 +38,7 @@ REMOVE_NODE = 0
 REMOVE_VALUE = 1
 
 
-class MuxTree(object):
+class MuxTree:
 
     """
     Object representing part of the tree from the root to leaves or another
@@ -150,7 +146,7 @@ class MuxTree(object):
         return True
 
 
-class MuxPlugin(object):
+class MuxPlugin:
     """
     Base implementation of Mux-like Varianter plugin. It should be used as
     a base class in conjunction with
@@ -161,6 +157,7 @@ class MuxPlugin(object):
     default_params = None
     paths = None
     debug = None
+    variant_ids = []
 
     def initialize_mux(self, root, paths, debug):
         """
@@ -235,7 +232,7 @@ class MuxPlugin(object):
         return sum(1 for _ in self)
 
 
-class OutputValue(object):  # only container pylint: disable=R0903
+class OutputValue:  # only container pylint: disable=R0903
 
     """ Ordinary value with some debug info """
 
@@ -285,7 +282,7 @@ class ValueDict(dict):  # only container pylint: disable=R0903
         self.yaml = srcyaml
         self.node = node
         self.yaml_per_key = {}
-        for key, value in iteritems(values):
+        for key, value in values.items():
             self[key] = value
 
     def __setitem__(self, key, value):
@@ -311,7 +308,7 @@ class ValueDict(dict):  # only container pylint: disable=R0903
 
     def iteritems(self):
         """ Slower implementation with the use of __getitem__ """
-        for key in iterkeys(self):
+        for key in self:
             yield key, self[key]
 
     def items(self):
@@ -319,7 +316,7 @@ class ValueDict(dict):  # only container pylint: disable=R0903
         return self.iteritems()
 
 
-class Control(object):  # Few methods pylint: disable=R0903
+class Control:  # Few methods pylint: disable=R0903
 
     """ Container used to identify node vs. control sequence """
 
@@ -367,7 +364,7 @@ class MuxTreeNode(tree.TreeNode):
                 elif ctrl.code == REMOVE_VALUE:
                     remove = []
                     regexp = re.compile(ctrl.value)
-                    for key in iterkeys(self.value):
+                    for key in self.value:
                         if regexp.match(key):
                             remove.append(key)
                     for key in remove:
